/**
 * @ngdoc Directive
 * @name directive-filter
 * @description
 *   the directives file includes all directive
 */

(function(){
    // 将车辆评级的描述分为多行
    // 仅用于ng-bind-html
    AuctionTypein.filter('levelDescSpliter', function(){
        return function(input){
            return input.replace(/。\n/g, '。<br/>');
        }
    });

    AuctionTypein.filter('wordSplit', function() {
        return function(input) {
            input = input || '';
            if(input.length > 2){
                var arr = input.match(/[\s\S]{2}/g);
                var out = '';
                arr.forEach(function(s){
                    out += '<span class="word-slice">';
                    out += s;
                    out += '</span>';
                });
                return out;
            }
            else{
                return input;
            }
        };
    });
	AuctionTypein.directive("selectCar", function() {
		return {
			restrict: "A",
			link: function(scope, elem, attr) {
				elem.bind('click', function() {
					switch (elem.attr('name')) {
						case 'brand_list':
							$('.brand_list').removeClass('currentCarModel')
							var brand = JSON.parse(elem.attr("data"));
							scope.setBrand(brand)
							scope.getSeries(1);
							break;
						case 'series_list':
							$('.series_list').removeClass('currentCarModel')
							var brand = JSON.parse(elem.attr("data"));
							scope.setSeries(brand, elem.attr("key"))
							scope.getModels(1);
							break;
						case 'model_list':
							var brand = JSON.parse(elem.attr("data"));
							scope.setModel(brand)
							scope.closeBrandModal();
							break;
					}
					elem.addClass('currentCarModel');
					scope.$apply();
				})
			}
		}
	})

	/**
	 * @memberof directives
	 * @param {object} item 页面上勾选的检测项
	 * @description  返回处理后的检测数据,
	 * 机械/内饰 部分选项是分项unit的无漏油/无异响/无蓝烟/无改装
	 * 每选择一个非正常项, 就把默认中的,此时的"其他"和默认的正常选项是不互斥的
	 */
    function getResult(item){
        var res = '';
        if( window.detectionData.isItemHasUnit(item.defaultVal) ){
            // 正常, 不用做复杂处理
            if(item.curVal){
                if(item.curVal == item.defaultVal){
                    res = item.defaultVal;
                }
                else{
                    var abnormalOptions = item.curVal.split(' ');
                    var defaultOptions = item.defaultVal.split('/');
                    // 检查每个原子项是否被勾选了非正常
                    res = defaultOptions.map(function(dop){
                        var detectOption = detectionData.isNewVersion() ? (dop.replace(/无/g,'有')) : dop.substr(1);
                        if( abnormalOptions.indexOf(detectOption) >= 0){
                            return '<span class="abnormal">' + detectOption + '</span>';
                        }
                        else{
                            return '<span>' + dop + '</span>';
                        }
                    }).join('/');
                }
                if(item.other){
                    res += ' <span>' + item.other + '</span>';
                }
            }
            else if(item.other){
                // 没有不正常的项 有其他的说明
                res = item.defaultVal + ' ' + item.other;
                // res = item.other;
            }
            else{
                res = item.defaultVal;
            }
        }
        // 下面的other代表abnormal
        else{
            // 已有值
            if(item.curVal){
                if(item.curVal != item.defaultVal){
                    res += '<span class="abnormal">'+item.curVal+'</span>';
                }
                else{
                    res = item.curVal
                }
                if(item.other){
                    res += ' <span class="abnormal">'+item.other+'</span>';
                }
            }
            // 有other
            else if(item.other){
                res = '<span class="abnormal">'+item.other+'</span>';
            }
            // 啥都没有
            else{
                res = item.defaultVal;
            }
        }
        return res;
    }

    AuctionTypein.directive('detectResult', function() {
        return {
            restrict: 'E',
            replace: true,
            scope: {
                item: '=item'
            },
            template: '<div class="item-sel" ng-bind-html="result"></div>',
            link: function(scope, elem, attrs){
                scope.result = getResult(scope.item);

                scope.$watch('item', function(newVal){
                    scope.result = getResult(newVal);
                }, true);
            }
        };
    });
    AuctionTypein.directive('picItem', function() {
        return {
            link: function(scope, elem, attrs){
                var replace_x;
                var replace_y;
                var dom;
                var itemW = $(window).width()/4;
                var touching = false;
                elem.on("touchstart",function(e){
                    touching = true;
                    if( navigator.userAgent.match(/Android/i) ) {   // if you already work on Android system, you can        skip this step
                        e.preventDefault();     //THIS IS THE KEY. You can read the difficult doc released by W3C to learn more.
                    }
                    setTimeout(function(){
                        if(touching){
                            var x = e.originalEvent.touches[0].pageX;
                            var y = e.originalEvent.touches[0].pageY -44;
                            dom = elem.clone()
                            $(".ds-pics").append(dom)
                            dom.css({
                                position:"absolute",
                                left:x-itemW/2,
                                top:y-itemW/2,
                                opacity:0.6
                            })

//                           e.preventDefault();
                        }
                    },500)

                }).on("touchmove",function(e){
                    if(dom&&e.originalEvent.touches&&e.originalEvent.touches.length){
                        var x = e.originalEvent.touches[0].pageX;
                        var y = e.originalEvent.touches[0].pageY -44;
                        replace_x = Math.floor(x/itemW);
                        replace_y = Math.floor(y/itemW);
                        dom.css({
                            left:x-itemW/2,
                            top:y-itemW/2
                        })
						e.preventDefault();
                    }

                }).on("touchend",function(){
                    if(dom){
                        dom.animate({
                            left:replace_x*itemW,
                            top:replace_y*itemW
                        },300)
                        setTimeout(function(){
                            dom.remove();
                            dom = null;
                        },300)
                        scope.movePic(attrs.index,replace_y*4+replace_x)
                    }

                    touching = false;
                })
            }
        };
    });
	AuctionTypein.directive("formatSelect", function(){
		return {
			restrict:"A",
			link: function(scope, elem, attr) {
				if(elem[0].selectedOptions[0]&&(elem[0].selectedOptions[0].value!==undefined) ){
					scope.carInfo.basic[elem[0].name]= elem[0].selectedOptions[0].innerHTML;
				}
				elem.bind('change',function(){
					scope.carInfo.basic[elem[0].name]= elem[0].selectedOptions[0].innerHTML;
				})
			}
		}
	})

	AuctionTypein.directive("fromCheyuan", function(){
		return {
			restrict:"A",
			link: function(scope, elem, attr) {
				location.href.indexOf('cheyuan_detection')>-1 ? scope.isFromCheyuan=true : scope.isFromCheyuan=false;
			}
		}
	})

	AuctionTypein.directive("scrollFocus", function(){
			return {
				restrict:"A",
				link: function(scope, elem, attr) {
					elem.bind('focus',function(e){
						setTimeout(function(){
							var topHeight = '-56px';
							$('.basic_Container').css({'top':"44px"})
						},500);

					})
					elem.bind('blur', function(e){
						$('.basic_Container').css({'top':'50px'})

					})
				}
			}
		})
	AuctionTypein.directive('touchLocate', function() {
		return {
			link: function(scope, elem, attr) {
				var $alpha_show = $('#alpha-show');
				var $brand_page = elem.find('.brandPage');
				var cliX;
				function translatePage(alpha) {
					var $cur_ele = $('#touch-trans-'+alpha);
					if ($cur_ele.length) {
						var top =$cur_ele.offset().top-54;
					}
					top && $brand_page.scrollTop($brand_page.scrollTop() + top)
				}
				elem.find('#touch-locate')
					.on('touchstart', function(e) {
						cliX = e.originalEvent.touches[0].clientX;
						$alpha_show.text(e.target.textContent).fadeIn(100);
						$(this).css('background', '#aaa');
						translatePage(e.target.textContent);
						e.preventDefault();
					})
					.on('touchmove', function(e) {
						var touch = e.originalEvent.touches[0];
						var ele = document.elementFromPoint(cliX, touch.clientY);
						$alpha_show.text(ele.textContent);
						translatePage(ele.textContent);
						e.preventDefault();
					})
					.on('touchend', function(e) {
						$alpha_show.fadeOut(100);
						$(this).css('background', '');
					})
					.on('click', function(e) {
						translatePage(e.target.textContent);
					});
			}
		}
	})
	AuctionTypein.directive("autoArea", function(){
			return {
				restrict:"A",
				link: function(scope, elem, attr) {

					elem.bind('focus',function(e){
						var u = navigator.userAgent;
						var isAndroid = u.indexOf('Android') > -1 || u.indexOf('Linux') > -1;
						if(!isAndroid){
							$('.basic_Container').css({'top':'-8px'});
							$('.basicHeader').css({"opacity": "0"})
						}
						$('.commentArea').css({'height':'200px', "opacity": "1"})
						$('.commentBox').css({"opacity": "0","display":"none","overflow-y":"hidden"});

					})
					elem.bind('blur', function(e){
						$('.basic_Container').css({'top':'50px'});
						$('.commentArea').css({'height':'500px', "opacity": "0"})
						$('.commentBox').css({"opacity": "1","display":"block","overflow-y":"scroll"})
						$('.basicHeader').css({"opacity": "1"})

					})
				}
			}
		})
    AuctionTypein.directive('decimalPlaces',function(){
        return {
            link:function(scope,ele,attrs){
                ele.bind('keypress',function(e){
                    var newVal=$(this).val()+(e.charCode!==0?String.fromCharCode(e.charCode):'');
                    if($(this).val().search(/(.*)\.[0-9][0-9]/)===0 && newVal.length>$(this).val().length){
                        e.preventDefault();
                    }
                });
            }
        };
    });
})();
