AuctionTypein.factory('Validator', function(){

    var YEARMODEL_REG = /(20|19)\d{2}/;
    // 只match一个就好
    function getYearFromModelName(modelName){
        // 20 或 19开头的 连续4个数字
        var mArr = modelName.match(YEARMODEL_REG);
        if(mArr && mArr.length >= 1){
            return Number(mArr[0]);
        }
        return false;
    }

    function validateManufacture(mDate, modelName){
        var problems = [];
        var now = new Date();
        // 保证自己对就行, 不管begin_at date
        if(!(moment(mDate).format('YYYY-MM-DD') < moment(now).format('YYYY-MM-DD') )){
            problems.push('出厂日期应早于今天');
        }
        if(modelName){
            var modelYear = getYearFromModelName(modelName);
            if(modelYear){
                var mYear = mDate.getFullYear();
                if(mYear < modelYear-2){
                    problems.push('出厂日期年份应该在车型年款的前两年之后');
                }
            }
        }

        return (problems.length == 0)? true : problems;
    }

    function validateBeginAt(mDate, bDate, modelName){
        var problems = [];
        var now = new Date();

        if(modelName){
            var modelYear = getYearFromModelName(modelName);
            if(modelYear){
                var dYear = bDate.getFullYear();
                if(dYear < modelYear-2){
                    problems.push('初次上牌年份应该在车型年款的前两年之后');
                }
            }
        }

        if(mDate){
            console.log(bDate)
            console.log(mDate)
            if(!(moment(bDate).format('YYYY-MM-DD') >= moment(mDate).format('YYYY-MM-DD') )){
                problems.push('初次上牌应晚于出厂日期');
            }
        }
        if(!(moment(bDate).format('YYYY-MM-DD') < moment(now).format('YYYY-MM-DD') )){
            problems.push('初次上牌应早于今天');
        }

        return (problems.length == 0)? true : problems;
    }

    function checkMileage(mileage){
        if(typeof mileage == 'string'){
            mileage = Number(mileage)
        }
        if(mileage > 99.99 || mileage < 0.01){
            return '表显里程应在0.01 ~ 99.99之间';
        }
        return true;
    }

    function checkPrice(newCarPrice, salePrice, pifaPrice){
        var problems = [];
        if(salePrice >= newCarPrice){
            problems.push('销售价格应低于新车指导价');
        }
        if( pifaPrice > salePrice){
            problems.push('批发价格应不高于销售价格');
        }
        return (problems.length == 0)? true : problems;
    }

    return {
        pubCarBase: function(basic){
            var problems = [];
            var mDate = basic.manufacture_date;
            var bDate = basic.begin_at;
            // 按照地推人员看到的从上到下的顺序

            // 表显里程
            if(basic && basic.mileage){
                var mileResult = checkMileage(basic.mileage);
                if(mileResult !== true){
                    problems.push(mileResult);
                }
            }

            // 3、出厂日期应该是根据年款往前最多两年往后最多4年，不得在今天之后 （输不进去）
            if(mDate){
                var mResult = validateManufacture(mDate, basic.model);
                if(mResult !== true){
                    problems = problems.concat(mResult)
                }
            }

            // 初次上牌
            if(bDate){
                var bResult = validateBeginAt(mDate, bDate, basic.model);
                if(bResult !== true){
                    problems = problems.concat(bResult);
                }
            }


            // 新车价 销售价
            if(basic.original_price && basic.price && basic.pifa_price){
                var piceResult = checkPrice(basic.original_price, basic.price, basic.pifa_price);
                if(piceResult !== true){
                    problems = problems.concat(piceResult);
                }
            }

            return (problems.length == 0)? true : problems;
        }
        
    }
})
