// 使用service 而不是modal, 因为需要每次注入都会new一次

/* 执行逻辑: 
        第一次: 获取scope, 生成modal
                将需要用的方法, 需要的数据结构绑在scope上, 声明watch等
                将传来的selected,pictures, other update到scope里
        之后:   直接调用已生成的modal,
                将传来的数据update到scope
                执行show
 */


AuctionTypein.service('DetectSelectService', function ($http, $ionicModal, $ionicPopup) {
    var tmpl = '../common/common_template/detectionSelector.html';

    var selectModal;
    var modalScope;
    var confirmBtnCallback = undefined;
    // scope data structure: 
    // {
    //     modal: {
    //         items: {name, checked}, // 包含other
    //         pictures,
    //     }
    // }

    function alertOnModal(title, content){
        selectModal['backdropClickToClose'] = false;
        var alertPopup = $ionicPopup.alert({
            title: title,
            template: content
        });
        alertPopup.then(function(res) {
            selectModal['backdropClickToClose'] = false;
        });
    }

    // 没有附带图片的提示
    function alertPicRequired(){
        alertOnModal('请上传图片', '当前检测项不正常时必须上传图片');
    }
    // 什么都没选的提示
    function alertNoCheck(){
        alertOnModal('请选择检测结果', '检测结果至少选择一项');
    }
    // 特殊检查项, 只填写了其他描述 没勾选的提示
    function alertOnlyOther(){
        alertOnModal('请选择检测结果', '除描述外, 检测结果还应至少选择一项');
    }

    

    // 附上事件处理
    function attachModal(scope){
        scope.modal = {
            // 点击确定后的操作
            confirmHandler: function(){
                // exports data
                var res = {};
                var items = modalScope.modal.items;
                var lastItemIndex = items.length - 1;
                // 判断是否check了item
                if(modalScope.modal.normalOtherMX){
                    if(haveNoCheck(modalScope.modal.items)){
                        alertNoCheck();
                        return;
                    }
                }
                else{
                    if(haveNoCheck(modalScope.modal.items)){
                        var otherItem = modalScope.modal.items[modalScope.modal.items.length - 1];
                        if(!otherItem.content.trim()){
                            alertNoCheck();
                        }
                        else{
                            alertOnlyOther();
                        }
                        return;
                    }
                    else if(onlyOtherChecked(modalScope.modal.items)){
                        alertOnlyOther();
                        return;
                    }
                }

                // 正常的话就只有正常
                if(items[0].checked){
                    res = {
                        selected: [items[0].name],
                        pictures: [],
                        other: ''
                    };
                    if(!modalScope.modal.normalOtherMX){
                        res.other = items[lastItemIndex].content || '';
                        if(res.other){
                            res.pictures = modalScope.modal.pictures || [];
                            if(res.pictures.length <= 0 && modalScope.modal.abnormalPicRequired){
                                alertPicRequired();
                                return false;
                            }
                        }
                    }
                }
                // 不正常的话, 才有picture
                else{
                    var selected = items.filter(function(item, index, arr){
                        if(index ==  0 || index == arr.length-1){
                            return false;
                        }
                        return item.checked;
                    }).map(function(item){
                        return item.name;
                    });

                    // 检查图片是否传了
                    var pictures = modalScope.modal.pictures;
                    if(modalScope.modal.abnormalPicRequired && pictures.length <=0){
                        alertPicRequired();
                        return false;
                    }

                    // other被check 才有other内容
                    var other = '';
                    if(items[lastItemIndex].checked){
                        other = items[lastItemIndex].content || '';
                        if(!other.trim()){
                            alertOnModal('请填写"其他"描述', '点选"其他"之后必须填写描述')
                            return false;
                        }
                    }
                    else if(!modalScope.modal.normalOtherMX){
                        other = items[lastItemIndex].content || '';
                    }
                    res = {
                        selected: selected,
                        pictures: pictures,
                        other: other
                    };
                }
                
                if(confirmBtnCallback instanceof Function){
                    confirmBtnCallback(res.selected, res.pictures, res.other);
                }
                selectModal.hide();
            },
            close: function(){
                selectModal.hide();
            }
        }
    }

    // 从传来的数据生成items, 便于repeat
    function buildItems(opt, modalScope){
        var items = opt.items, selected = opt.selected;
        var res = items.map(function(item){
            var checked = selected? selected.some(function(s){
                    return s == item
                }) : false;
            return {
                name: item,
                checked: checked,
                content: ''
            };
        });

        var otherChecked = Boolean(modalScope.modal.normalOtherMX && opt.other);
        res.push({
            checked: otherChecked,
            name: '其他',
            content: opt.other || ''
        });
        // 如果没有选中任何项, 
        // 在初始时就选中默认项
        var someItemChecked = res.some(function(item){
            return item.checked;
        });
        if(!someItemChecked){
            res[0].checked = true;
        }
        return res;
    }

    // 用于watch中, 判断是否发生了abnormal项的check
    function newAbnormalChecked(newVal, oldVal){
        return newVal.some(function(item, index){
            // 跳过第一个
            if(index == 0){ return false;}
            // 有没有新选中的
            return item.checked && !oldVal[index].checked;
        })
    }
    // 用于showPic中, 判断是否有abnormal项的check
    function hasAbnormalChecked(items, other){
        if(other){
            return true;
        }
        var hasAbnormal = items.some(function(item, index){
            if(index == 0){
                return false;
            }
            else{
                return item.checked;
            }
        })
        return hasAbnormal;
    }

    function haveNoCheck(items){
        return !items.some(function(item){
            return item.checked;
        });
    }
    function onlyOtherChecked(items){
        var checkedIndex;
        var haveChecked = items.some(function(item, index){
            checkedIndex = index;
            return item.checked;
        });
        if(haveChecked){
            if(checkedIndex == items.length -1 ){
                return true;
            }
        }
        return false;
    }


    return {
        show: function(opt, callback){
            confirmBtnCallback = callback;
            var that = this;
            if(selectModal){
                this.update(opt);
                selectModal.show();
            }
            else{
                this.init(opt.scope, function(modal){
                    that.update(opt);
                    modal.show();
                    setTimeout(function(){
                        // other项 需要单独处理
                        // that.bindEvent();
                    }, 50);
                });
            }
        },
        // 需要在第一次调用的时候实例化, 通过传过来的$scope
        init: function(scope, callback){
            modalScope = scope;
            $ionicModal.fromTemplateUrl(tmpl, {
                scope: scope,
                animation: 'slide-in-up'
            }).then(function(modal){
                selectModal = modal;
                attachModal(scope);
                modalScope.modal.showPic = false;

                if(callback instanceof Function){
                    callback(modal);
                }
            }.bind(this));
            modalScope.showupload = function(){
                // if(typeof CheNiu != "undefined"){
                    // CheNiu.pickCarImagesCallback = function(filePaths){
                    //
                    // };
                    // CheNiu.pickCarImages(20,30-modalScope.modal.pictures.length,12);
                    Jockey.send('CapturePicBridge', {
                        maxPicCount: 1 //用户最大可上传的照片数量
                    }, function(data) {
                     // *  {
                     // *      urls: ['http://img.souche.com/20160112/png/0.png']
                     // *  }
                     // alert(JSON.stringify(data.urls));
                            filePaths = data.urls
                            filePaths.forEach(function(filepath){
                                if(modalScope.modal.pictures.indexOf(filepath)==-1){
                                    modalScope.modal.pictures.push(filepath)
                                }
                            })
                            modalScope.$digest();
                     });
                // }else{
                //     modalScope.modal.pictures.push("http://img.souche.com/files/default/84145234D6D86B139759C93EF5F8E576_285x240.jpg@1e_285w_240h_1c_0i_1o_90Q_1x.jpg?"+Math.random())
                // }
            }
            modalScope.previewPic = "";
            modalScope.hidePreview = function(){
                modalScope.previewModal.hide();
                    // CheNiu&&CheNiu.setNavColor(appColor)
            };
            modalScope.del = function(){
                modalScope.modal.pictures.forEach(function(p,i){
                    if(p==modalScope.previewPic){
                        modalScope.modal.pictures.splice(i,1)
                    }
                })
                modalScope.previewModal.hide();
            };
            modalScope.previewModal;
            $ionicModal.fromTemplateUrl('../common/common_template/imgpreview.html', {
                scope: modalScope,
                animation: 'slide-in-up'
            }).then(function(modal) {
                modalScope.previewModal = modal;
            });
            modalScope.preview = function(file){
                modalScope.previewPic = file;
                modalScope.previewModal.show();
                setTimeout(function(){
                    // window.CheNiu&&CheNiu.setNavColor("#111111")
                },300)
            }
            // 监控items的check
            modalScope.$watch('modal.items', function(newVal, oldVal){
                if(!newVal || !oldVal){
                    return;
                }
                if(modalScope.modal.normalOtherMX){
                    // 点了默认正常项, 其他都置为un-checked
                    if(newVal[0].checked == true && oldVal[0].checked == false){
                        modalScope.modal.items.forEach(function(item, index){
                            if(index == 0){ return; }
                            item.checked = false;
                        });
                        modalScope.modal.showPic = false;
                        return;
                    }

                    // 新点了其他项, 正常项un-check
                    if( newAbnormalChecked(newVal, oldVal) ){
                        if(newVal[0].checked){
                            newVal[0].checked = false;
                        }
                        if(!modalScope.modal.showPic){
                            modalScope.modal.showPic = true;
                        }
                    }

                    if(haveNoCheck(newVal)){
                        if(modalScope.modal.showPic){
                            modalScope.modal.showPic = false;
                        }
                    }
                }
                else{
                    var newOther = newVal[newVal.length - 1];
                    // 点了默认正常项, 其他都置为un-checked
                    if(newVal[0].checked == true && oldVal[0].checked == false){
                        modalScope.modal.items.forEach(function(item, index){
                            if(index == 0 || index == modalScope.modal.items.length-1){ return; }
                            item.checked = false;
                        });
                        // other未填写
                        if( !newOther.content.trim() ){
                            modalScope.modal.showPic = false;
                        }
                        return;
                    }
                    
                    // 有不正常项 一定是显示图片的 正常项不选中的
                    if( newAbnormalChecked(newVal, oldVal) ){
                        if(newVal[0].checked){
                            newVal[0].checked = false;
                        }
                        if(!modalScope.modal.showPic){
                            modalScope.modal.showPic = true;
                        }
                        return;
                    }

                    var oldOther = oldVal[oldVal.length - 1];
                    if(newOther.content.trim() && !oldOther.content.trim()){
                        modalScope.modal.showPic = true;
                    }
                    else if( !newOther.content.trim() && oldOther.content.trim() && !hasAbnormalChecked(newVal) ){
                        modalScope.modal.showPic = false;
                    }

                    if(haveNoCheck(newVal) && !newOther.content.trim()){
                        if(modalScope.modal.showPic){
                            modalScope.modal.showPic = false;
                        }
                    }
                }
                // console.log(newVal[newVal.length-1]);
            }, true);
        },
        // options, selected, pictures, other
        update: function(opt){
            modalScope.modal.title = opt.title;
            modalScope.modal.pictures = opt.pictures||[];

            // MX means: Mutual exclusion 互斥
            // 正常项 和 other项 是否需要互斥
            modalScope.modal.normalOtherMX = !window.detectionData.isItemHasUnit(opt.items[0]);
            modalScope.modal.items = buildItems(opt, modalScope);


            modalScope.modal.abnormalPicRequired = opt.abnormalPicRequired;
            modalScope.modal.showPic = !!opt.other || (opt.selected && opt.selected != opt.items[0]);
        }
    }

});

// 无破损&|&##老化
