AuctionTypein.factory('Validator', function(){

    var YEARMODEL_REG = /(20|19)\d{2}/;
    // 只match一个就好
    function getYearFromModelName(modelName){
        // 20 或 19开头的 连续4个数字
        var mArr = modelName.match(YEARMODEL_REG);
        if(mArr && mArr.length >= 1){
            return Number(mArr[0]);
        }
        return false;
    }

    function validateVincode(vincode) {
        var problems = [];
        var regstr = /^[0-9A-Z]*$/g;
        if (/^[0-9]*$/g.test(vincode)) {
            problems.push('VIN码不能全是数字');
        } else if (/^[a-zA-Z]*$/g.test(vincode)) {
            problems.push('VIN码不能全是字母');
        } else if (!/^[0-9a-zA-Z]*$/g.test(vincode)) {
            problems.push('VIN码必须是数字或字母')
        } else if (vincode.length < 17) {
            problems.push('VIN码不足17位');
        }

        return (problems.length == 0)? true : problems;

    }

//    function valiEngineCapacity(enginenum) {
//        var problems = [];
//        if (parseFloat(enginenum) <= 0) {
//            problems.push('排量不能小于0');
//        }
//        // else if (parseFloat(enginenum) >= 10) {
//        //     problems.push('排量不能大于10');
//        // }
//
//        return (problems.length == 0)? true : problems;
//    }

    function validateManufacture(mDate, modelName){
        var problems = [];
        var now = new Date();
        // 保证自己对就行, 不管begin_at date
        if(!(moment(mDate).format('YYYY-MM-DD') < moment(now).format('YYYY-MM-DD') )){
            problems.push('出厂日期应早于今天');
        }
        if(modelName){
            var modelYear = getYearFromModelName(modelName);
            if(modelYear){
                var mYear = mDate.getFullYear();
                // if(mYear < modelYear-2 || mYear > modelYear+4){
                if(mYear < modelYear-2 ){
                    problems.push('出厂日期年份应该在车型年款的前两年之后');
                }
            }
        }

        return (problems.length == 0)? true : problems;
    }

    function validateBeginAt(mDate, bDate, modelName){
        var problems = [];
        var now = new Date();

        if(modelName){
            var modelYear = getYearFromModelName(modelName);
            if(modelYear){
                var dYear = bDate.getFullYear();
                // if(dYear < modelYear-2 || dYear > modelYear+4){
                if(dYear < modelYear-2){
                    problems.push('初登日期年份应该在车型年款的前两年之后');
                }
            }
        }

        if(mDate){
            if(!(moment(bDate).format('YYYY-MM-DD') > moment(mDate).format('YYYY-MM-DD') )){
                problems.push('初登日期应晚于出厂日期');
            }
        }
        if(!(moment(bDate).format('YYYY-MM-DD') < moment(now).format('YYYY-MM-DD') )){
            problems.push('初登日期应早于今天');
        }

        return (problems.length == 0)? true : problems;
    }

    function checkMileage(mileage){
        if(typeof mileage == 'string'){
            mileage = Number(mileage)
        }
        if(mileage > 99.99 || mileage < 0.01){
            return '表显里程应在0.01 ~ 99.99之间';
        }
        return true;
    }

    function checkPrice(newCarPrice, salePrice, pifaPrice){
        var problems = [];

        if (salePrice && salePrice < 0.1) {
            problems.push('零售价格不应小于0.1万元');
        }
        if (pifaPrice && pifaPrice < 0.1) {
            problems.push('批发价格不应小于0.1万元');
        }
        if (newCarPrice && salePrice && salePrice >= newCarPrice) {
            problems.push('销售价格应低于新车指导价');
        }
        if (pifaPrice && salePrice && pifaPrice > salePrice) {
            problems.push('批发价格应不高于销售价格');
        }

        return (problems.length == 0) ? true : problems;
    }

    return {
        pubCarBase: function(basic){
            var problems = []; 
            var mDate = basic.manufacture_date;
            var bDate = basic.begin_at;
            // 按照地推人员看到的从上到下的顺序

            //VIN码
            if (basic && basic.vin_code) {
                var vinResult = validateVincode(basic.vin_code);
                if (vinResult !== true) {
                    problems.push(vinResult);
                }
            }

            //排量
//            if (basic && basic.engine_capacity) {
//                var engineCpResult = valiEngineCapacity(basic.engine_capacity);
//                if (engineCpResult !== true) {
//                    problems.push(engineCpResult);
//                }
//            }

            // 表显里程
            if(basic && basic.mileage){
                var mileResult = checkMileage(basic.mileage);
                if(mileResult !== true){
                    problems.push(mileResult);
                }
            }

            // 3、出厂日期应该是根据年款往前最多两年往后最多4年，不得在今天之后 （输不进去）
            if(mDate){
                var mResult = validateManufacture(mDate, basic.model);
                if(mResult !== true){
                    problems = problems.concat(mResult)
                }
            }

            // 初登日期
            if(bDate){
                var bResult = validateBeginAt(mDate, bDate, basic.model);
                if(bResult !== true){
                    problems = problems.concat(bResult);
                }
            }


            // 新车价 销售价
            var piceResult = checkPrice(basic.original_price, basic.price, basic.pifa_price);
            if(piceResult !== true){
                problems = problems.concat(piceResult);
            }

            return (problems.length == 0)? true : problems;
        }
        
    }
})
