// 通过vin码推荐车型
// 用户选择车型
// 通过车型code获取车型配置数据
// 将配置数据转成ruby后端可接受的数据
AuctionTypein.factory('ModelConfigTransfer', function(){
    var OTHER = 'other';
    // 车体
    var bodyTransfer = {
        5: 'two',  // 两厢车
        6: 'three',  // 三厢车
        1: 'suv',  // SUV
        2: 'mpv',  // MPV
        3: 'roadster',  // 敞篷
        4: 'sports',  // 跑车
        7: 'estate',  // 旅行车
        8: 'pcut'  // 皮卡车
    };
    // 燃料/供油
    var fuelTransfer = {
        '1': 'gasoline',  // 汽油
        '2': 'diesel',  // 柴油
        '3': 'mixture',   // 混合
        '4': 'electric',  // 电动
        '6': OTHER
    };
    // 排放标准
    var emissionTransfer = {
        '4': '国一',
        '3': '国二',
        '1': '国三',
        '2': '国四',
        '5': '国五'
        // '欧Ⅰ' : 'o1',
        // '欧Ⅱ' : 'o2',
        // '欧Ⅲ': 'o3',
        // '欧Ⅳ': 'o4',
        // '欧Ⅴ': 'o5'
    };
    var driveTypeTransfer = {
        5: 'mr',    // 中置后驱
        7: 'mwd',    // 中置四驱
        9: 'ff',    // 前置前驱
        11: 'fr',    // 前置后驱
        13: 'fwd',    // 前置四驱
        15: 'rr',    // 后置后驱
        17: 'rwd',    // 后置四驱
    };

    // 颜色
    var colorTransfor = {
        2: "#888787",   // 深灰色
        4: "#ffffff",   // 白色
        11: "#79386a",   // 紫色
        5: "#ca2128",   // 红色
        // : "#98cb68",   // 绿色
        6: "#396bb3",   // 蓝色
        1: "#efecec",   // 银色
        9: "#e7d3ae",   // 香槟色
        10: "#fbdc04",  // 黄色
        3: "#000000"  // 黑色
    };
   // 变速箱
    var gearTypeTransfer = {
        '1': 'MT-手动',     // 手动变速器
        '2': 'AT-自动',     // 自动变速器
        '3': '手自一体',     // 手自一体变速器
        '4': 'CVT-无级',     // 双离合变速器
        '5': 'DSG-双离合',     // CVT无级变速器
        // '6': 'AMT机械式变速',     // AMT机械式变速器
        // '7': '序列式变速器',     // 序列式变速器
        // '8': '电动车单速变速器',     // 电动车单速变速器
    };

    // 进气方式
    var intakeTransfer = {
        '1': 'naturally_aspirated',   // 自然吸气
        // '2': 'vortex_supercharger',   // 增压(已废弃)
        '3': 'double_boost',   // 双涡轮增压
        // '4': 'quadruple_boost',   // 四涡轮增压
        '5': 'mechanical_and_turbo',   // 机械+涡轮增压 / 双增压
        '7': 'supercharged',   // 机械增压
        '9': 'vortex_supercharger',   // 涡轮增压
        '11': OTHER,   // 其他
    };

    // 配置列表
    var configList = {
        // 防抱死制动系统
        fbsz: 'abs',
        // 导航系统    
        ddxt: 'gps',
        // 音响系统    
        dvdd: 'dvd',
        // 倒车影像系统  
        dcyx: 'back_eye_camera',
        // 电动调节前座椅     
        ddtj: 'power_seat',
        // 天窗  
        qjtc: 'skylights',
        // 前后电动升降窗     
        qhdd: 'electric_windows',
        // 安全气囊    
        aqql: 'srs',
        // 空调  
        zdhw: 'air_condition',
        // 定速巡航    
        dsxh: 'cruise',
        // 倒车雷达
        backRada: 'reversing_radar',
        // 真皮座椅
        leatherSeat: 'leather_seats',

        // 紧急制动辅助系统
        brakeAssist: 'eba',
        // 电子稳定程序系统
        stabilityControl: 'esps',
        // 中控锁
        centralDoorLock: 'central_locking',
        // 备用轮胎
        spareWheel: 'spare_tire',
        // 电子动后视镜
        backMirrorElectricAdjustment: 'power_mirrors',
        // 遥控钥匙/智能钥匙
        remoteKey: 'smart_key',
        // 一键启动
        yjqd: 'one_key',

        // 一键启动    yjqd
        // 大灯清洗    ddtc 
        // 车载雷达   czld
        // 前座椅加热   zpzy
        // 氙气大灯    sqdd
    };

    return {
        // 排放标准
        getEnvironment: function(nameCode){
            return emissionTransfer[nameCode];
        },
        // 几厢车
        getBody: function(nameCode){
            var res = bodyTransfer[nameCode];
            return res || OTHER;
        },
        // 变速箱类型
        getGearboxType: function(typeCode){
            return gearTypeTransfer[typeCode] || '其他';
        },
        driveType: function(typeCode){
            return driveTypeTransfer[typeCode] || OTHER;
        },
        // 进气方式 只有这两种
        getInletType: function(intakeType){
            return intakeTransfer[intakeType] || OTHER;
        },
        // 燃油类型  供油系统
        getFuelType: function(nameCode){
            return fuelTransfer[nameCode] || OTHER;
        },
        getColor: function(colorCode){
            return colorTransfor[colorCode];
        },
        getConfigList: function(data, scope){
            if(data.configList && Array.isArray(data.configList)){
                
                var count = [];

                data.configList.forEach(function(cc){
                    var code = cc.configurationCode;
                    var matchedServerKey = configList[code];
                    // 没有这个项目, 跳过
                    if(!matchedServerKey){
                        return;
                    }
                    var result = undefined;
                    var val = cc.configurationValue;
                    if( val == 2){
                        result = 1;
                    }
                    else if(val == 1 || val == 4){
                        result = 0;
                    }
                    else if(val == 3){
                        result = 10;
                    }
                    scope.carInfo.configuration[matchedServerKey] = result;

                    count.push({
                        name: matchedServerKey,
                        value: result
                    })
                });
                console.log(count);
            }
        }
    }
})